@@ -145,82 +145,82 @@ namespace detail
 
 	// Binary operators
 	template <typename T> 
-	tmat2x4<T> operator+ (
+	GLM_FUNC_DECL tmat2x4<T> operator+ (
 		tmat2x4<T> const & m, 
 		typename tmat2x4<T>::value_type const & s);
 
 	template <typename T> 
-	tmat2x4<T> operator+ (
+	GLM_FUNC_DECL tmat2x4<T> operator+ (
 		tmat2x4<T> const & m1, 
 		tmat2x4<T> const & m2);
 
 	template <typename T> 
-	tmat2x4<T> operator- (
+	GLM_FUNC_DECL tmat2x4<T> operator- (
 		tmat2x4<T> const & m, 
 		typename tmat2x4<T>::value_type const & s);
 
 	template <typename T> 
-	tmat2x4<T> operator- (
+	GLM_FUNC_DECL tmat2x4<T> operator- (
 		tmat2x4<T> const & m1, 
 		tmat2x4<T> const & m2);
 
 	template <typename T> 
-	tmat2x4<T> operator* (
+	GLM_FUNC_DECL tmat2x4<T> operator* (
 		tmat2x4<T> const & m, 
 		typename tmat2x4<T>::value_type const & s);
 
 	template <typename T> 
-	tmat2x4<T> operator* (
+	GLM_FUNC_DECL tmat2x4<T> operator* (
 		typename tmat2x4<T>::value_type const & s, 
 		tmat2x4<T> const & m);
 
 	template <typename T>
-	typename tmat2x4<T>::col_type operator* (
+	GLM_FUNC_DECL typename tmat2x4<T>::col_type operator* (
 		tmat2x4<T> const & m, 
 		typename tmat2x4<T>::row_type const & v);
 
 	template <typename T> 
-	typename tmat2x4<T>::row_type operator* (
+	GLM_FUNC_DECL typename tmat2x4<T>::row_type operator* (
 		typename tmat2x4<T>::col_type const & v, 
 		tmat2x4<T> const & m);
 
 	template <typename T>
-	tmat4x4<T> operator* (
+	GLM_FUNC_DECL tmat4x4<T> operator* (
 		tmat2x4<T> const & m1, 
 		tmat4x2<T> const & m2);
 		
 	template <typename T>
-	tmat2x4<T> operator* (
+	GLM_FUNC_DECL tmat2x4<T> operator* (
 		tmat2x4<T> const & m1, 
 		tmat2x2<T> const & m2);
 		
 	template <typename T>
-	tmat3x4<T> operator* (
+	GLM_FUNC_DECL tmat3x4<T> operator* (
 		tmat2x4<T> const & m1, 
 		tmat3x2<T> const & m2);
 
 	template <typename T> 
-	tmat2x4<T> operator/ (
+	GLM_FUNC_DECL tmat2x4<T> operator/ (
 		tmat2x4<T> const & m, 
 		typename tmat2x4<T>::value_type const & s);
 
 	template <typename T> 
-	tmat2x4<T> operator/ (
+	GLM_FUNC_DECL tmat2x4<T> operator/ (
 		typename tmat2x4<T>::value_type const & s, 
 		tmat2x4<T> const & m);
 
 	// Unary constant operators
 	template <typename T> 
-	tmat2x4<T> const operator-  (
+	GLM_FUNC_DECL tmat2x4<T> const operator-  (
 		tmat2x4<T> const & m);
 
 	template <typename T> 
-	tmat2x4<T> const operator-- (
+	GLM_FUNC_DECL tmat2x4<T> const operator-- (
 		tmat2x4<T> const & m, 
 		int);
 
 	template <typename T> 
-	tmat2x4<T> const operator++ (
+	GLM_FUNC_DECL tmat2x4<T> const operator++ (
 		tmat2x4<T> const & m, 
 		int);
 
